###########################################################################
#
#   Copyright (c) 2000 Morten W. Petersen <morten@esol.no>
#	Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.3 $


__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import default__class_init__
import Acquisition
import AccessControl.Role
import OFS.Folder
import Products
import base_item
import string
import smtplib # FIXME
import category
import news_letter_folder

manage_add_news_folder_form = HTMLFile('news_folder_add', globals())

def manage_add_news_folder(self, id, title, number_of_messages_in_display,
				description, newsletter_mailhost,
				newsletter_originator,amplifier,
				REQUEST=None, RESPONSE=None):
	"Add an instance of the NewsFolder class"

	self._setObject(id, news_folder(id, title, number_of_messages_in_display,
					description, newsletter_mailhost,
					newsletter_originator, amplifier))

	if RESPONSE and REQUEST:

		RESPONSE.redirect(REQUEST['URL3'])


class news_folder(
	Products.ZCatalog.CatalogAwareness.CatalogAware,
	OFS.Folder.Folder,
	Persistent,
	Acquisition.Implicit,
	AccessControl.Role.RoleManager,
	base_item.base_item
	):
	"Documentation string"

	meta_type = 'NewsFolder'
	icon = 'misc_/NewsFolder/Folder_icon.gif'
	#default_catalog = 'Catalog'

	_properties = (
		{'id':'title', 'type':'string'},
		{'id':'description', 'type':'text'},
		{'id':'newsletter_mailhost', 'type':'string'},
		{'id':'newsletter_originator', 'type':'string'},
		{'id':'amplifier', 'type':'string'},
		{'id':'number_of_messages_in_display', 'type':'int'}
		)

	meta_types = (
		{'name':'Category', 'action':'manage_add_category_form'},
		)

	manage_add_category_form = category.manage_add_category_form
	manage_add_category = category.manage_add_category
	manage_add_news_letter_folder = news_letter_folder.manage_add_news_letter_folder

	__ac_permissions__ = (
		('View management screens',
		 ('manage_tabs', 'manage_main')),
		('Change Permissions',
		 ('manage_access',)),
		('Add Category',
		 ('manage_add_category', 'manage_add_category_form')),
		('View NewsFolders',
		 ('',)),
		)

	index_html = HTMLFile('news_folder_index', globals())
	display = HTMLFile('news_folder_display', globals())
	#make_newsletter = HTMLFile('make_newsletter', globals())
	#newsletter_sent = HTMLFile('newsletter_sent', globals())

	base_edit = HTMLFile('news_folder_edit', globals())

	product_name = 'NewsFolder'

	def __init__(self, id, title='', number_of_messages_in_display=2,
				description='', newsletter_mailhost='',
				newsletter_originator='', amplifier=''):
		"""Initialize the class instance,  and add default forums."""

		self.id = id
		self.title = title
		self.number_of_messages_in_display = number_of_messages_in_display
		self.description = description
		self.newsletter_mailhost = newsletter_mailhost
		self.newsletter_originator = newsletter_originator
		self.amplifier = amplifier
		self.published_via_email = 0

		self.counter = 0

		try:

			self.index_object()

		except AttributeError:

			# ZCatalog isn't available

			pass

		self.manage_add_category('Internal', 'This category contains internal news', 0)
		self.manage_add_category('Public', 'This container contains public news', 1)

		self.manage_add_news_letter_folder('Newsletters', 'Newsletters sent to the outside world..')

		self.manage_addDTMLMethod('standard_html_header', 'Helpful navigation and such',
								  HTMLFile('standard_html_header', globals()))
		self.manage_addDTMLMethod('standard_html_footer', '',
								  HTMLFile('standard_html_footer', globals()))


	def get_news_letter_folder(self):
		"""Returns the newsletter folder."""

		return self.objectValues('NewsLetterFolder')[0]


	def get_unique_id(self):
		"""Returns a unique identifier."""

		try:

			return self.getParentNode().get_unique_id()

		except:

			self.counter = self.counter + 1
			
			return str(self.counter)


	def get_unmailed_news(self, number_of_news_items=None):
		"""Returns a list of news items not yet posted via email, if
		the maximum number of news items is specified, it will return the
		oldest items."""

		news_items = self.get_news(number_of_news_items=None)

		news_items = filter(lambda x: not x.published_via_email, news_items)

		news_items.sort(
			lambda x,y: cmp(
			x.bobobase_modification_time, y.bobobase_modification_time
			))

		if number_of_news_items:

			return news_items[-number_of_news_items:]

		else:

			return news_items

		
	def get_news_sorted(self, number_of_news_items=None):
		"""Returns a list of news items sorted, if the maximum number
		of news items is specified, it will return the most recent items."""

		news_items = self.get_news()

		news_items.sort(
			lambda x,y: cmp(
			x.bobobase_modification_time, y.bobobase_modification_time
			))

		if number_of_news_items:

			return news_items[:number_of_news_items]

		else:

			return news_items


	def get_news(self, number_of_news_items=10):
		"""Returns all news messages."""

		news_items = []

		for category in self.objectValues('Category'):

			map(news_items.append, category.get_news())

		if number_of_news_items:

			return news_items[:number_of_news_items]

		else:

			return news_items


	def get_display_news(self):
		"""Returns a list of news items for the display."""

		return self.get_news(self.number_of_messages_in_display)



default__class_init__(news_folder)

